@@ -126,13 +126,13 @@ class SingleCmd(object):
 
     ## used for debug what command string be executed
     __DEBUG__ = False
+    cmdname = None
+    execute_kwargs = ('stdin','interact', 'via_shell', 'with_extend_output')
 
-    execute_kwargs = ('stdin','interact', 'via_shell')
-
-    #{{{def __init__(self, cmdname, opt_style=0):
-    def __init__(self, cmdname, opt_style=0):
-        self.cmdname = cmdname
-        if not cmdname or not cmdexists(cmdname):
+    #{{{def __init__(self, cmdname=None, opt_style=0):
+    def __init__(self, cmdname=None, opt_style=0):
+        self.cmdname = cmdname or self.cmdname
+        if not self.cmdname or not cmdexists(self.cmdname):
             raise CommandNotFound()
         self.opt_style = opt_style
     #}}}
@@ -159,8 +159,8 @@ class SingleCmd(object):
         return self.execute(call, **_kwargs)
     #}}}
 
-    #{{{def execute(self, command, stdin=None, interact=False, via_shell=False):
-    def execute(self, command, stdin=None, interact=False, via_shell=False):
+    #{{{def execute(self, command, stdin=None, interact=False, via_shell=False, with_extend_output=False):
+    def execute(self, command, stdin=None, interact=False, via_shell=False, with_extend_output=False):
         """execute command
 
         @param subprocess.PIPE stdin 
@@ -203,9 +203,12 @@ class SingleCmd(object):
                 proc.stdout.close()
                 proc.stderr.close()
     
-            if status != 0:
-                raise CommandExecutedFalur(status, stderr_value)
-            return stdout_value
+            if not with_extend_output:
+                if status != 0:
+                    raise CommandExecutedFalur(status, stderr_value)
+                return stdout_value
+            else:
+                return (status, stdout_value)
     #}}}
 
     #{{{def __repr__(self):
@@ -219,15 +222,15 @@ class CmdDispatcher(SingleCmd):
     ## prefix of sub command
     subcmd_prefix = None
 
-    #{{{def __init__(self, cmdname, opt_style=0, subcmd_prefix=None):
-    def __init__(self, cmdname, opt_style=0, subcmd_prefix=None):
+    #{{{def __init__(self, cmdname=None, opt_style=0, subcmd_prefix=None):
+    def __init__(self, cmdname=None, opt_style=0, subcmd_prefix=None):
         """Constructor
 
         @param str cmdname command name
         @param str opt_style option style
         @param str subcmd_prefix prefix of sub command
         """
-        self.subcmd_prefix = subcmd_prefix
+        self.subcmd_prefix = self.subcmd_prefix or subcmd_prefix
         super(CmdDispatcher, self).__init__(cmdname, opt_style)
     #}}}
 
@@ -248,3 +251,12 @@ class CmdDispatcher(SingleCmd):
         return super(CmdDispatcher, self)._callProcess(*args, **kwargs)
     #}}}
 pass
+
+#{{{def use_helper():
+def use_helper():
+    """allow to use a shortcut functions for creating Cmd
+    """
+    import __builtin__
+    __builtin__.__dict__['_c'] = SingleCmd
+    __builtin__.__dict__['_d'] = CmdDispatcher
+#}}}
